#
# spec file for package rebootmgr
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rebootmgr
Version:        3.2+git20250213.bff65b1
Release:        1.1
Summary:        Automatic controlled reboot during a maintenance window
License:        GPL-2.0-only AND LGPL-2.1-or-later
Group:          System/Base
URL:            https://github.com/SUSE/rebootmgr
Source:         %{name}-%{version}.tar.xz
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  timezone
BuildRequires:  pkgconfig(libeconf) >= 0.7.6
BuildRequires:  pkgconfig(libsystemd) >= 257

%description
RebootManager is a dbus service to execute a controlled reboot after updates in a defined maintenance window.

If you updated a system with e.g. transactional updates or a kernel update was applied, you can tell rebootmgrd with rebootmgrctl, that the machine should be reboot at the next possible time. This can either be immediately or during a defined maintenance window.

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
mkdir -p %{buildroot}%{_sbindir}
ln -sf ../bin/rebootmgrctl  %{buildroot}%{_sbindir}/rebootmgrctl

%check
%meson_test

%pre
%service_add_pre rebootmgr.service
if [ -f /etc/rebootmgr.conf ] && [ ! -f /etc/rebootmgr/rebootmgr.conf.d/20-old-rebootmgr.conf ]; then
    mkdir -p /etc/rebootmgr/rebootmgr.conf.d ||:
    mv /etc/rebootmgr.conf /etc/rebootmgr/rebootmgr.conf.d/20-old-rebootmgr.conf
fi

%post
%service_add_post rebootmgr.service

%preun
%service_del_preun rebootmgr.service

%postun
%service_del_postun rebootmgr.service

%files
%license COPYING COPYING.LIB
%doc NEWS
%dir %{_datadir}/rebootmgr
%{_datadir}/rebootmgr/rebootmgr.conf
%{_unitdir}/rebootmgr.service
%{_bindir}/rebootmgrctl
%{_sbindir}/rebootmgrctl
%{_libexecdir}/rebootmgrd
%{_datadir}/bash-completion/completions/rebootmgrctl
%{_mandir}/man1/rebootmgrctl.1%{?ext_man}
%{_mandir}/man5/rebootmgr.conf.5%{?ext_man}
%{_mandir}/man8/rebootmgrd.8%{?ext_man}
%{_mandir}/man8/rebootmgr.service.8%{?ext_man}

%changelog
* Thu Feb 13 2025 kukuk@suse.com
- Update to version 3.2+git20250213.bff65b1:
  * Release version 3.2
  * Handle case that main-window is not set correct
  * rebootmgrd: fix instantly strategy
* Tue Feb 11 2025 kukuk@suse.com
- Update to version 3.0+git20250211.a56a554:
  * rebootmgr.service: fix Type=notify
- Readd compat symlink of rebootmgrctl for tukit
* Wed Jan 29 2025 kukuk@suse.com
- Update to version 3.0+git20250129.eed876f:
  * Release version 3.1
  * rebootmgrd: fix check if new strategy is valid
* Tue Jan 28 2025 kukuk@suse.com
- Update to version 3.0+git20250128.8fa577c:
  * Import version 3.0 based on sd-varlink
* Mon Jan 27 2025 kukuk@suse.com
- Update to version 3.0+git20250127.73667d7:
  * rebootmgrctl: implement verbose dump-config verb
  * Fix search path for vendor config file
  * Add CI with openSUSE container
  * Add new methods and use UID auth
- Add timezone to BuildRequires for test suite
* Wed Jan 15 2025 kukuk@suse.com
- Update to version 3.0+git20250114.f74a9d5:
  * Add bash-completion for rebootmgrctl
* Thu Dec 19 2024 kukuk@suse.com
- Update to version 3.0+git20241219.7166827:
  * Remove left overs from dbus related manual page
  * Use int64 to parse JSON for time_t
  * Set varlink info
  * Move announce_ready() call to a later place
  * Require libeconf 0.7.5
  * Free event loop in destroy context.
  * Add missing error reply
  * Remove unused log_type variable
  * Add internal error to varlink interface
  * Move varlink definition into own file
  * Update manual pages
* Mon Nov 11 2024 Thorsten Kukuk <kukuk@suse.com>
- Add compatibility symlink for rebootmgrctl to sbin
* Fri Nov  8 2024 kukuk@suse.com
- Update to version 2.6+git20241108.fc0c103:
  * Fix installation of .so man pages
  * Rework manpage generation
  * Switch from configure.ac to meson
  * Document that timezones are not supported
  * Release version 2.5
* Fri May 24 2024 kukuk@suse.com
- Update to version 2.4+git20240524.30e5383:
  * Move tmpfiles.d/soft-reboot-cleanup.conf to aaa_base
* Fri May  3 2024 kukuk@suse.com
- Remove rcrebootmgr symlink
- Update to version 2.4+git20240503.5b98913:
  * Don't generate html documentation anymore
  * Fix manual page dependencies for parallel build
  * Update configure.ac
  * Fix soft-reboot detection in forced mode
* Fri Mar 15 2024 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.4
  - Make sure systemctl reboot will not switch to soft-reboot
    automatically
* Fri Mar  8 2024 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.3
  - rebootmgrd: add verbose mode
  - Enable verbose mode in rebootmgr.service by default
* Wed Feb  7 2024 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.2
  - Make sure /run/reboot-needed get's deleted after a soft-reboot
* Fri Aug 18 2023 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.1
  - Support systemctl soft-reboot (systemd >= v254)
* Fri Aug 11 2023 Avinesh Kumar <avinesh.kumar@suse.com>
- Typo fix in spec description
* Wed Oct 26 2022 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.0
  - Remove outdated etcd code
  - Fix issue#10:
    Reboots happen at the first moment of the maintenance window
* Wed Mar 10 2021 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.3.1
  - Move all dbus config files to /usr/share/dbus-1
* Wed Jul  1 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.3
  - Fix documentation of is-active return  value [bsc#1173484]
  - Fix crash if rebootmgrd is already running
  - Fix systemctl restart; also removes KillMode=none from systemd
    service file [bsc#1186510]
* Mon Jun  8 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.2
  - depend on dbus and not network as we disabled etcd support
    [bsc#1172518]
* Thu Apr 30 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.1
  - fix systemd and tmpfiles.d directory path
* Thu Apr 30 2020 Thorsten Kukuk <kukuk@suse.com>
- Use official tar archive
* Mon Apr 27 2020 Thorsten Kukuk <kukuk@suse.com>
- Adjust BuildRequires
* Mon Apr 27 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.0
  - Rewrite rebootmgrd to not depend on glib and dbus-glib
* Wed Jan 29 2020 Thorsten Kukuk <kukuk@suse.com>
- Disable ectd support (no current etcd C-library available)
* Wed Nov 27 2019 Ignaz Forster <iforster@suse.com>
- Fix %%posttrans script returning an error code
* Mon Nov  4 2019 kukuk@suse.de
- Update to version 0.20.1
  - added a memory allocation check
* Mon Sep  9 2019 kukuk@suse.de
- Fix %%config for backward compatibility
* Fri Sep  6 2019 kukuk@suse.de
- Update to version 0.20
  - add support to write changes back to /etc/rebootmgr.conf
  - fix compilation with glibc 2.30 [bsc#1197850]
* Wed Aug 28 2019 kukuk@suse.de
- Preserve /etc/rebootmgr.conf if modified
* Tue Aug 27 2019 kukuk@suse.de
- Update to version 0.19
  - use libeconf for /usr/etc move
* Thu Jan 17 2019 kukuk@suse.de
- Update to version 0.18
  - allow to compile without etcd support
* Wed Mar 28 2018 kukuk@suse.de
- Update to version 0.17
  - fix some bugs around etcd locks and reboot fast path
* Mon Mar 19 2018 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Wed Jan 10 2018 kukuk@suse.de
- Update to version 0.16
  - fix compile problem with new json-c [bsc#1075329]
* Wed Sep 13 2017 kukuk@suse.de
- Update to version 0.15
  - Adjust for systemd >= 230
* Fri Mar 31 2017 kukuk@suse.de
- Update to version 0.14
  - Allow to have no maintenance window configured [bsc#1031619]
* Wed Mar 15 2017 kukuk@suse.de
- Update to version 0.13
  - Don't reboot outside maintenance window if getting the etcd
    lock takes too long [bsc#1028060]
* Fri Mar  3 2017 kukuk@suse.de
- Update to version 0.12
  - Rewrote reboot code to not block dbus if we wait for etcd locks
    [bsc#1026298]
  - Fix rebootmgr.service dependencies
  - Check input for maintenance window for correct syntax before
    sending to the daemon [bsc#1026220]
* Mon Feb 27 2017 kukuk@suse.de
- Update to version 0.11
  - Implement unlocking of a machine_id not equal to our own [bsc#1026273]
  - Watch for correct key when waiting for lock [bsc#1026274]
* Thu Feb 16 2017 kukuk@suse.de
- Update to version 0.10
  - Fix typos in documentation
  - Fix compilation on 32bit systems
* Tue Feb 14 2017 kukuk@suse.de
- Update to version 0.9
  - Finish rebootmgrctl manual page
* Wed Feb  8 2017 kukuk@suse.de
- Update to version 0.8
  - Implement changing number of hosts holding a lock at the same time
  - Add new and enhance existing manual pages
* Thu Jan 12 2017 kukuk@suse.de
- Update to version 0.7
  - Fix dbus name in systemd service file
* Thu Jan 12 2017 kukuk@suse.de
- Update to version 0.6
  - Add etcd lock support
* Mon Jan  9 2017 kukuk@suse.de
- Update to version 0.5
  - Rewrite for better dbus support
  - Merges typo.patch
* Tue Dec 13 2016 kukuk@suse.de
- Fix typo in executing systemctl
* Wed Nov 23 2016 kukuk@suse.de
- Update to versin 0.3
  - fix path for systemctl
* Wed Nov 23 2016 kukuk@suse.de
- Update to version 0.2
  - implement maintenance window
  - implement rebootmgrctl get-strategy
* Sun Nov 20 2016 kukuk@suse.de
- Initial submission
